==> HTML-Menu-TreeView-0.6.3.tar.gz: HTML-Menu-TreeView-0.6.3/htdocs/style/Crystal/32/html-menu-treeview/preload.js <==
folderClosed = new Image(32,32);
folderClosed.src='/style/Crystal/32/html-menu-treeview/folderClosed.gif';
plusNodeClosed = new Image(32,32);
plusNodeClosed.src='/style/Crystal/32/html-menu-treeview/plusNodeClosed.gif';
lastPlusNodeClosed = new Image(32,32);
lastPlusNodeClosed.src='/style/Crystal/32/html-menu-treeview/lastPlusNodeClosed.gif';
clasicPlusNodeClosed = new Image(32,32);
clasicPlusNodeClosed.src='/style/Crystal/32/html-menu-treeview/clasicPlusNodeClosed.gif';
clasicLastPlusNodeClosed = new Image(32,32);
clasicLastPlusNodeClosed.src='/style/Crystal/32/html-menu-treeview/clasicLastPlusNodeClosed.gif';
folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(32,32);
folderGray.src='/style/Crystal/32/html-menu-treeview/folderGray.gif';
folderGreen = new Image(32,32);
folderGreen.src='/style/Crystal/32/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(32,32);
folderViolet.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(32,32);
folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(32,32);
folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(32,32);
folderHtmlClosed.src='/style/Crystal/32/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(32,32);
folderFavoriteClosed.src='/style/Crystal/32/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(32,32);
folderTextClosed.src='/style/Crystal/32/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(32,32);
folderLockedClosed.src='/style/Crystal/32/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(32,32);
folderCrystalClosed.src='/style/Crystal/32/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(32,32);
folderVideoClosed.src='/style/Crystal/32/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(32,32);
folderPrintClosed.src='/style/Crystal/32/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(32,32);
folderImageClosed.src='/style/Crystal/32/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(32,32);
folderSoundClosed.src='/style/Crystal/32/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(32,32);
folderImportantClosed.src='/style/Crystal/32/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(32,32);
folderTarClosed.src='/style/Crystal/32/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.6.4.tar.gz: HTML-Menu-TreeView-0.6.4/htdocs/style/Crystal/32/html-menu-treeview/preload.js <==
folderClosed = new Image(32,32);
folderClosed.src='/style/Crystal/32/html-menu-treeview/folderClosed.gif';
plusNode = new Image(32,32);
plusNode.src='/style/Crystal/32/html-menu-treeview/plusNode.gif';
lastplusNode = new Image(32,32);
lastplusNode.src='/style/Crystal/32/html-menu-treeview/lastplusNode.gif';
clasicplusNode = new Image(32,32);
clasicplusNode.src='/style/Crystal/32/html-menu-treeview/clasicplusNode.gif';
clasicLastplusNode = new Image(32,32);
clasicLastplusNode.src='/style/Crystal/32/html-menu-treeview/clasicLastplusNode.gif';
folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(32,32);
folderGray.src='/style/Crystal/32/html-menu-treeview/folderGray.gif';
folderGreen = new Image(32,32);
folderGreen.src='/style/Crystal/32/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(32,32);
folderViolet.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(32,32);
folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(32,32);
folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(32,32);
folderManClosed.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(32,32);
folderHtmlClosed.src='/style/Crystal/32/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(32,32);
folderFavoriteClosed.src='/style/Crystal/32/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(32,32);
folderTextClosed.src='/style/Crystal/32/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(32,32);
folderLockedClosed.src='/style/Crystal/32/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(32,32);
folderCrystalClosed.src='/style/Crystal/32/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(32,32);
folderVideoClosed.src='/style/Crystal/32/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(32,32);
folderPrintClosed.src='/style/Crystal/32/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(32,32);
folderImageClosed.src='/style/Crystal/32/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(32,32);
folderSoundClosed.src='/style/Crystal/32/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(32,32);
folderImportantClosed.src='/style/Crystal/32/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(32,32);
folderTarClosed.src='/style/Crystal/32/html-menu-treeview/folderTarClosed.gif';
